==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/AppconfigRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfig;
import microsoft.dynamics.crm.entity.collection.request.AppconfiginstanceCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.NavigationsettingCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class AppconfigRequest extends EntityRequest<Appconfig> {

    public AppconfigRequest(ContextPath contextPath, Optional<Object> value) {
        super(Appconfig.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public AppmoduleRequest appmodule_appconfig() {
        return new AppmoduleRequest(contextPath.addSegment("appmodule_appconfig"), Optional.empty());
    }

    public SystemuserRequest appconfig_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_modifiedby"), Optional.empty());
    }

    public SystemuserRequest appconfig_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_modifiedonbehalfby"), Optional.empty());
    }

    public NavigationsettingCollectionRequest appconfig_navigationsetting() {
        return new NavigationsettingCollectionRequest(
                        contextPath.addSegment("appconfig_navigationsetting"), Optional.empty());
    }

    public NavigationsettingRequest appconfig_navigationsetting(String navigationsettingid) {
        return new NavigationsettingRequest(contextPath.addSegment("appconfig_navigationsetting").addKeys(new NameValue(navigationsettingid.toString())), Optional.empty());
    }

    public SystemuserRequest appconfig_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_createdonbehalfby"), Optional.empty());
    }

    public AppconfiginstanceCollectionRequest appconfig_appconfiginstance() {
        return new AppconfiginstanceCollectionRequest(
                        contextPath.addSegment("appconfig_appconfiginstance"), Optional.empty());
    }

    public AppconfiginstanceRequest appconfig_appconfiginstance(String appconfiginstanceid) {
        return new AppconfiginstanceRequest(contextPath.addSegment("appconfig_appconfiginstance").addKeys(new NameValue(appconfiginstanceid.toString())), Optional.empty());
    }

    public SystemuserRequest appconfig_createdby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_createdby"), Optional.empty());
    }

    public OrganizationRequest organization_appconfig() {
        return new OrganizationRequest(contextPath.addSegment("organization_appconfig"), Optional.empty());
    }

    @Function(name = "RetrieveUnpublished")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<Appconfig> retrieveUnpublished() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new FunctionRequestReturningNonCollectionUnwrapped<Appconfig>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublished"), Appconfig.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/request/AppconfigRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfig;
import microsoft.dynamics.crm.entity.collection.request.AppconfiginstanceCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.NavigationsettingCollectionRequest;

@JsonIgnoreType
public class AppconfigRequest extends EntityRequest<Appconfig> {

    public AppconfigRequest(ContextPath contextPath, Optional<Object> value) {
        super(Appconfig.class, contextPath, value);
    }

    public AppmoduleRequest appmodule_appconfig() {
        return new AppmoduleRequest(contextPath.addSegment("appmodule_appconfig"), Optional.empty());
    }

    public SystemuserRequest appconfig_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_modifiedby"), Optional.empty());
    }

    public SystemuserRequest appconfig_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_modifiedonbehalfby"), Optional.empty());
    }

    public NavigationsettingCollectionRequest appconfig_navigationsetting() {
        return new NavigationsettingCollectionRequest(
                        contextPath.addSegment("appconfig_navigationsetting"), Optional.empty());
    }

    public NavigationsettingRequest appconfig_navigationsetting(String navigationsettingid) {
        return new NavigationsettingRequest(contextPath.addSegment("appconfig_navigationsetting").addKeys(new NameValue(navigationsettingid.toString())), Optional.empty());
    }

    public SystemuserRequest appconfig_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_createdonbehalfby"), Optional.empty());
    }

    public AppconfiginstanceCollectionRequest appconfig_appconfiginstance() {
        return new AppconfiginstanceCollectionRequest(
                        contextPath.addSegment("appconfig_appconfiginstance"), Optional.empty());
    }

    public AppconfiginstanceRequest appconfig_appconfiginstance(String appconfiginstanceid) {
        return new AppconfiginstanceRequest(contextPath.addSegment("appconfig_appconfiginstance").addKeys(new NameValue(appconfiginstanceid.toString())), Optional.empty());
    }

    public SystemuserRequest appconfig_createdby() {
        return new SystemuserRequest(contextPath.addSegment("appconfig_createdby"), Optional.empty());
    }

    public OrganizationRequest organization_appconfig() {
        return new OrganizationRequest(contextPath.addSegment("organization_appconfig"), Optional.empty());
    }

    @Function(name = "RetrieveUnpublished")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<Appconfig> retrieveUnpublished() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new FunctionRequestReturningNonCollectionUnwrapped<Appconfig>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublished"), Appconfig.class, _parameters);
    }

}
